###############
Getting started
###############

Quick overview to get up to speed with Odin.

.. toctree::
   :maxdepth: 1

   creating-resources
   loading-and-saving-data
   mapping-between-resources
   polymorphism-and-abstract-resources
